==> ktp-accounts-kcm-15.04.3.tar.xz: ktp-accounts-kcm-15.04.3/plugins/salut/ktpaccountskcm_plugin_salut.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Salut connection manager.
Comment[ast]=Interfaz d'usuariu de configuración de cuenta personalizada pa cuentes qu'usen el xestor de conexones Salut.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Salut menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Salut.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Salut.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Salut.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Salut.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Salut-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Salut.
Comment[en_GB]=Custom account configuration user interface for accounts using the Salut connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Salut.
Comment[et]=Saluti ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Salut-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Salut ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Salut.
Comment[hu]=Egyedi beállítófelület a Salut kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Salut.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Salut.
Comment[kk]=Salut байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​គណនី​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី​​ ​ដែល​​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់ Salut ។
Comment[ko]=Salut 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Salut ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Salut tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Salut“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Salut verbindingenbeheerder gebruiken.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Salut.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Salut.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Salut.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Salut.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Salut.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Salut.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Salut.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Салут.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Салут.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Salut.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Salut.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Salut.
Comment[tr]=Salut bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштування облікового запису за допомогою керування з’єднаннями Salut.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Salut.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Salut connection manager.xx
Comment[zh_CN]=通过 Salut 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Salut 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Salut Account Configuration User Interface
Name[ast]=Interfaz d'usuariu de configuración de cuenta Salut
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Salut
Name[ca]=Interfície d'usuari de configuració de compte de Salut
Name[ca@valencia]=Interfície d'usuari de configuració de compte de Salut
Name[cs]=Uživatelské rozhraní nastavení účtu Salut
Name[da]=Brugerflade til Salut kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Salut-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Salut
Name[en_GB]=Salut Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Salut
Name[et]=Saluti konto seadistamise kasutajaliides
Name[fi]=Salut-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Salut ».
Name[gl]=Interface de usuario para a configuración de contas de Salut
Name[hu]=Salut azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Salut
Name[it]=Interfaccia utente di configurazione account Salut
Name[kk]=Salut тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី Salut
Name[ko]=Salut 계정 설정 사용자 인터페이스
Name[lt]=Salut paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Salut-konto
Name[nds]=Salut-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Salut accountconfiguratie
Name[pl]=Nakładka graficzna do ustawiania konta Salut
Name[pt]=Interface de Configuração de Contas do Salut
Name[pt_BR]=Interface de configuração de contas do Salut
Name[ro]=Interfață de configurare a conturilor Salut
Name[ru]=Интерфейс для настройки учётной записи Salut
Name[sk]=Používateľské rozhranie konfigurácie účtu Salut
Name[sl]=Uporabniški vmesnik za nastavitev računov Salut
Name[sr]=Корисничко сучеље за подешавање налога под Салутом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Салутом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Salutom
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Salutom
Name[sv]=Användargränssnitt för inställning av Salut-konton
Name[tr]=Salut Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштування Salut
Name[wa]=Eterface uzeu d' apontiaedje des contes Salut
Name[x-test]=xxSalut Account Configuration User Interfacexx
Name[zh_CN]=Salut 账户用户配置界面
Name[zh_TW]=Salut 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_salut
X-KDE-PluginInfo-Author=Florian Reinhard
X-KDE-PluginInfo-Email=florian.reinhard@googlemail.com
X-KDE-PluginInfo-Name=salut
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm-15.12.3.tar.xz: ktp-accounts-kcm-15.12.3/plugins/salut/ktpaccountskcm_plugin_salut.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Salut connection manager.
Comment[ast]=Interfaz d'usuariu de configuración de cuenta personalizada pa cuentes qu'usen el xestor de conexones Salut.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Salut menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Salut.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Salut.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Salut.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Salut.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Salut-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Salut.
Comment[en_GB]=Custom account configuration user interface for accounts using the Salut connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Salut.
Comment[et]=Saluti ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Salut-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Salut ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Salut.
Comment[hu]=Egyedi beállítófelület a Salut kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Salut.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Salut.
Comment[kk]=Salut байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​គណនី​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី​​ ​ដែល​​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់ Salut ។
Comment[ko]=Salut 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Salut ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Salut tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Salut“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Salut verbindingenbeheerder gebruiken.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Salut.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Salut.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Salut.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Salut.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Salut.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Salut.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Salut.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Салут.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Салут.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Salut.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Salut.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Salut.
Comment[tr]=Salut bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштування облікового запису за допомогою керування з’єднаннями Salut.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Salut.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Salut connection manager.xx
Comment[zh_CN]=通过 Salut 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Salut 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Salut Account Configuration User Interface
Name[ast]=Interfaz d'usuariu de configuración de cuenta Salut
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Salut
Name[ca]=Interfície d'usuari de configuració de compte de Salut
Name[ca@valencia]=Interfície d'usuari de configuració de compte de Salut
Name[cs]=Uživatelské rozhraní nastavení účtu Salut
Name[da]=Brugerflade til Salut kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Salut-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Salut
Name[en_GB]=Salut Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Salut
Name[et]=Saluti konto seadistamise kasutajaliides
Name[fi]=Salut-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Salut ».
Name[gl]=Interface de usuario para a configuración de contas de Salut
Name[hu]=Salut azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Salut
Name[it]=Interfaccia utente di configurazione account Salut
Name[kk]=Salut тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី Salut
Name[ko]=Salut 계정 설정 사용자 인터페이스
Name[lt]=Salut paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Salut-konto
Name[nds]=Salut-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Salut accountconfiguratie
Name[pl]=Nakładka graficzna do ustawiania konta Salut
Name[pt]=Interface de Configuração de Contas do Salut
Name[pt_BR]=Interface de configuração de contas do Salut
Name[ro]=Interfață de configurare a conturilor Salut
Name[ru]=Интерфейс для настройки учётной записи Salut
Name[sk]=Používateľské rozhranie konfigurácie účtu Salut
Name[sl]=Uporabniški vmesnik za nastavitev računov Salut
Name[sr]=Корисничко сучеље за подешавање налога под Салутом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Салутом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Salutom
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Salutom
Name[sv]=Användargränssnitt för inställning av Salut-konton
Name[tr]=Salut Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштування Salut
Name[wa]=Eterface uzeu d' apontiaedje des contes Salut
Name[x-test]=xxSalut Account Configuration User Interfacexx
Name[zh_CN]=Salut 账户用户配置界面
Name[zh_TW]=Salut 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_salut
X-KDE-PluginInfo-Author=Florian Reinhard
X-KDE-PluginInfo-Email=florian.reinhard@googlemail.com
X-KDE-PluginInfo-Name=salut
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
